==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/JourneyCustomMessage.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class JourneyCustomMessage(data: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage = {
    import JourneyCustomMessage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
      .builder()
      .optionallyWith(
        data.map(value => __string.unwrap(value): java.lang.String)
      )(_.data)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.JourneyCustomMessage.ReadOnly =
    zio.aws.pinpoint.model.JourneyCustomMessage.wrap(buildAwsValue())
}
object JourneyCustomMessage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.JourneyCustomMessage =
      zio.aws.pinpoint.model.JourneyCustomMessage(data.map(value => value))
    def data: Option[__string]
    def getData: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("data", data)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
  ) extends zio.aws.pinpoint.model.JourneyCustomMessage.ReadOnly {
    override val data: Option[__string] = scala
      .Option(impl.data())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
  ): zio.aws.pinpoint.model.JourneyCustomMessage.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/JourneyCustomMessage.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class JourneyCustomMessage(
    data: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage = {
    import JourneyCustomMessage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
      .builder()
      .optionallyWith(data.map(value => value: java.lang.String))(_.data)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.JourneyCustomMessage.ReadOnly =
    zio.aws.pinpoint.model.JourneyCustomMessage.wrap(buildAwsValue())
}
object JourneyCustomMessage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.JourneyCustomMessage =
      zio.aws.pinpoint.model.JourneyCustomMessage(data.map(value => value))
    def data: Optional[__string]
    def getData: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("data", data)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
  ) extends zio.aws.pinpoint.model.JourneyCustomMessage.ReadOnly {
    override val data: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.data())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.JourneyCustomMessage
  ): zio.aws.pinpoint.model.JourneyCustomMessage.ReadOnly = new Wrapper(impl)
}
